/* 
 * Eneso Hotkey Library
 * Eneso Tecnología de Adaptación, S.L. 
 */

#include <windows.h>
#include "ehotkey.h"

static HWND hotkey_window = NULL;

static EHotkeyCb	user_key_cb	= NULL;

static LRESULT CALLBACK
hotkey_wnd_proc	(HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam);


	void
ehotkey_init (EHotkeyCb key_cb)
{
	WNDCLASSW	wc;

	user_key_cb = key_cb;

	memset (&wc, 0, sizeof (wc));

	wc.hInstance   		= GetModuleHandle (NULL);
	wc.lpfnWndProc  	= hotkey_wnd_proc;
	wc.lpszClassName	= TEXT ("ehotkey");

	RegisterClassW (&wc);

	hotkey_window = CreateWindowExW (0, (LPCTSTR) "ehotkey", (LPCTSTR) "ehotkey",
			WS_POPUP, 0, 0, 1, 1, NULL, NULL, wc.hInstance, NULL);	
}

	void
ehotkey_terminate (void)
{
	hotkey_window = NULL;

	DestroyWindow (hotkey_window);
}

	int
ehotkey_register (int id, uint16_t mods, uint16_t key)
{
	uint16_t	modifiers	 = 0;

	if (mods & EHK_MOD_SHIFT)
		modifiers |= MOD_SHIFT;
	if (mods & EHK_MOD_CTRL)
		modifiers |= MOD_CONTROL;
	if (mods & EHK_MOD_ALT)
		modifiers |= MOD_ALT;

	return RegisterHotKey (hotkey_window, id, modifiers, key);
}

	void
ehotkey_unregister (int id)
{
	UnregisterHotKey (hotkey_window, id);
}

	static LRESULT CALLBACK
hotkey_wnd_proc (HWND hWnd, UINT uMsg, WPARAM wParam, LPARAM lParam)
{
	if (uMsg == WM_HOTKEY)
	{
		if (user_key_cb)
			user_key_cb (wParam);
	}

	return DefWindowProcW (hWnd, uMsg, wParam, lParam);
}
